# ---
# jupyter:
#   jupytext:
#     cell_metadata_filter: all
#     formats: ipynb,py:percent
#     notebook_metadata_filter: all,-language_info,-toc,-latex_envs
#     text_representation:
#       extension: .py
#       format_name: percent
#       format_version: '1.3'
#       jupytext_version: 1.3.2
#   kernelspec:
#     display_name: Python 3
#     language: python
#     name: python3
#   latex_metadata:
#     chead: Quiz questions, January 18, 2020
#     lhead: E340 Day 5
#   pdf_metadata:
#     text1: html header success
# ---

# %% [markdown] ctype="question" qnum="1"
# 1.  Suppose we have a one layer atmosphere with ε=1 above a black
#     surface as in Dessler Fig. 4.6. Does adding a second opaque (ε=1)
#     layer (Dessler Figure 4.7) increase the greenhouse effect, decrease
#     the greenhouse effect, or leave the greenhouse effect unchanged?
#
#     A.  increase
#
#     B.  decrease
#
#     C.  no change

# %% [markdown] ctype="question" qnum="2"
# 2.  Suppose a planet's average surface temperature is about 320 K. In the one-layer
#     semi-transparent atmosphere shown below (and seen in your reading),
#     what would the approximate long-wave atmospheric emissivity ε need to be in
#     order for $T_g$=320 K, if the average shorwave flux was $I_0=400\ W\,m^{-2}$. (Hint, look at equations 5-6 in the reading).
#
#     A.  0.54
#
#     B.  0.65
#
#     C.  0.77
#
#     D.  0.88
#
#     E.  0.95

# %% [markdown] ctype="question" qnum="2"
# ![fig1](media/image1.png)

# %% [markdown] ctype="question" qnum="3"
# 3. Given a one-layer atmosphere like problem 2, but with $\epsilon=0.8$, $T_G$=306 K, $T_1$=258 K, $I_0$ = 300 $W\,m^{-2}$,  calculate the greenouse effect. (choose the closest number)
#
# A. -121 $W\,m^2$
#
# B. +121 $W\,m^2$
#
# C. +197 $W\,m^2$
#
# D. +221 $W\,m^2$
#
# E. +324 $W\,m^2$

# %% [markdown] ctype="question" qnum="4"
# 4.  According to the figure in Trenberth et al. 2009 below, how big is the Earth's greenhouse effect?
#
# A.  85 $W\,m^{-2}$
#
# B. 157 $W\,m^{-2}$
#
# C. 254 $W\,m^{-2}$
#
# D. 285 $W\,m^{-2}$
#
# E. 333 $W\,m^{-2}$

# %% [markdown] ctype="question" qnum="3"
# ![fig2](media/image2.png)
